from functools import lru_cache
from .. import Influxable


class RawQuery:
    def __init__(self, str_query):
        self.str_query = str_query

    def execute(self):
        return self.raw_response

    @property
    def raw_response(self):
        return self._resolve()

    @lru_cache(maxsize=None)
    def _resolve(self, *args, **kwargs):
        instance = Influxable.get_instance()
        return instance.execute_query(query=self.str_query, method='post')



from .query import RawQuery


class InfluxDBAdmin:
    @staticmethod
    def show_databases():
        return RawQuery('SHOW DATABASES').execute()

    @staticmethod
    def show_measurements():
        return RawQuery('SHOW MEASUREMENTS').execute()

    @staticmethod
    def show_queries():
        return RawQuery('SHOW QUERIES').execute()

    @staticmethod
    def show_series():
        return RawQuery('SHOW SERIES').execute()

    @staticmethod
    def show_stats():
        return RawQuery('SHOW STATS').execute()

    @staticmethod
    def show_users():
        return RawQuery('SHOW USERS').execute()
